@@ -19,20 +19,20 @@
 # Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
 # MA 02111-1307 USA
 
-id = "91a5d26283954446c922ddf3f21a569baa2fb6f4"
-date = "2016-06-26 20:16:42 +0000"
+id = "a1664d2de7910a01819d19ba13160d191d4391a4"
+date = "2016-10-10 17:31:34 +0000"
 branch = "None"
-tag = "lalframe-v1.4.1"
+tag = "lalframe-v1.4.2"
 if tag == "None":
     tag = None
 author = "Adam Mercer <adam.mercer@ligo.org>"
 builder = "Adam Mercer <adam.mercer@ligo.org>"
-committer = "Adam Mercer <ramercer@gmail.com>"
+committer = "Adam Mercer <adam.mercer@ligo.org>"
 status = "CLEAN: All modifications committed"
 version = id
 verbose_msg = """Branch: None
-Tag: lalframe-v1.4.1
-Id: 91a5d26283954446c922ddf3f21a569baa2fb6f4
+Tag: lalframe-v1.4.2
+Id: a1664d2de7910a01819d19ba13160d191d4391a4
 
 Builder: Adam Mercer <adam.mercer@ligo.org>
 Repository status: CLEAN: All modifications committed"""
@@ -53,9 +53,9 @@ def check_match(foreign_id, onmismatch="raise"):
     """
     if onmismatch not in ("raise", "warn"):
         raise ValueError(onmismatch + " is an unrecognized value of onmismatch")
-    if foreign_id == "91a5d26283954446c922ddf3f21a569baa2fb6f4":
+    if foreign_id == "a1664d2de7910a01819d19ba13160d191d4391a4":
         return
-    msg = "Program id (91a5d26283954446c922ddf3f21a569baa2fb6f4) does not match given id (%s)." % foreign_id
+    msg = "Program id (a1664d2de7910a01819d19ba13160d191d4391a4) does not match given id (%s)." % foreign_id
     if onmismatch == "raise":
         raise VersionMismatchError(msg)
 
